.. _physics:

=============================
 Physics
=============================


The Python Package SymPy can be used to symbolically solve physics problems
on Classical Mechanics, Continuum Mechanics, Control Systems, High-Energy
Physics, Optics, Quantum Mechanics, Units and Vector algebra.

For physics tutorials, please check out:

* `Biomechanics Tutorials <../../tutorials/physics/biomechanics>`_
* `Mechanics Tutorials <../../tutorials/physics/mechanics>`_
* `Continuum Mechanics Tutorials <../../tutorials/physics/continuum_mechanics>`_
* `Control Tutorials <../../tutorials/physics/control>`_
